@@ -1,4 +1,4 @@
-epi.sssimpleestc <- function(N = 1E+06, xbar, sigma, epsilon, error = "relative", nfractional = FALSE, conf.level = 0.95){
+epi.sssimpleestc <- function(N = NA, xbar, sigma, epsilon, error = "relative", nfractional = FALSE, conf.level = 0.95){
     N. <- 1 - ((1 - conf.level) / 2)
     z <- qnorm(N., mean = 0, sd = 1)
     
@@ -10,14 +10,12 @@ epi.sssimpleestc <- function(N = 1E+06, xbar, sigma, epsilon, error = "relative"
     # Page 74 Levy and Lemeshow (equation 3.15):
     n <- (z^2 * N * Vsq) / (z^2 * Vsq + ((N - 1) * epsilon.r^2))
 
-    if(nfractional == TRUE){
-      n <- n
-    }
-    
-    if(nfractional == FALSE){
-      n <- ceiling(n)
-    }
+    # Finite population correction:
+    n <- ifelse(is.na(N), n, (n * N) / (n + (N - 1)))
     
+    # Fractional:
+    n <- ifelse(nfractional == TRUE, n, ceiling(n))
+
     rval <- n
     return(rval)
 }
\ No newline at end of file
